==> familia_0.1.tar.gz: familia/src/file/individual.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_INDIVIDUAL_H
#define _FILE_INDIVIDUAL_H

#include <gtkmm.h>
#include <glibmm/ustring.h>
#include <cairomm/cairomm.h>

#include "name.h"
#include "position.h"
#include "boundary.h"

enum gender_type {
  male, female, unknownGender
};

namespace file {

class Individual {
public:
  typedef Individual _Myt;
  typedef Glib::ustring _String;
  typedef Position _Position;
  typedef Boundary _Boundary;
  typedef Name _Name;
protected:
  int _id;
  bool _deceased;
  gender_type _gender;

  _Name _name;
  _Position _position;
  _Boundary _boundary;

  short child_number;
  _String _viewId;
public:
  Individual();
  Individual(int identifier);

  int getId();
  void setId(int identifier);

  _Name& name();
  _Position& position();
  _Boundary& boundary();
  _String& viewId();

  bool isDead();
  gender_type getGender();

  _Myt& setDead(bool value);
  _Myt& setGender(gender_type type);

  void draw(const Cairo::RefPtr<Cairo::Context>& cr);
};

}

#endif

==> familia_0.1.2.tar.gz: familia/src/file/individual.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_INDIVIDUAL_H
#define _FILE_INDIVIDUAL_H

#include <gtkmm.h>
#include <glibmm/ustring.h>
#include <cairomm/cairomm.h>

#include "unique.h"
#include "name.h"
#include "position.h"
#include "boundary.h"

enum gender_type {
  male, female, unknownGender
};

namespace file {

class Individual : public Unique {
public:
  typedef Individual _Myt;
  typedef Glib::ustring String;
  typedef Position _Position;
  typedef Boundary _Boundary;
  typedef Name _Name;
protected:
  bool _deceased;
  gender_type _gender;

  _Name _name;
  _Position _position;
  _Boundary _boundary;

  short child_number;
  String _viewId;
public:
  Individual();
  virtual ~Individual();

  _Name& name();
  _Position& position();
  _Boundary& boundary();
  String& viewId();

  bool isDead();
  gender_type getGender();

  _Myt& setDead(bool value);
  _Myt& setGender(gender_type type);

  void draw(const Cairo::RefPtr<Cairo::Context>& cr);
};

}

#endif
